==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/sr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "Personal activity feed for %s" : "Довод личних активности корисника %s",
    "Your feed URL is invalid" : "УРЛ вашег довода није исправан",
    "Your settings have been updated." : "Поставке су ажуриране.",
    "Mail" : "Поштом",
    "Stream" : "Записник",
    "Activities" : "Активности",
    "Error loading activities" : "Грешка при учитавању активности",
    "No activities" : "Нема активности",
    "This stream will show events like additions, changes & shares" : "Овде ће се приказати догађаји попут додавања, измена или дељења",
    "There are no events for this filter" : "Нема догађаја за овај филтер",
    "Activity notification" : "Обавештења о активностима",
    "All Activities" : "Све активности",
    "Activities by you" : "Ваше активности",
    "Activities by others" : "Активности других",
    "\"remote user\"" : "\"удаљени корисник\"",
    "in %s" : "у %s",
    "%s and %s" : "%s и %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s и <strong %s>још %n</strong>","%s и <strong %s>још %n</strong>","%s и <strong %s>још %n</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s и још %n","%s и још %n","%s и још %n"],
    "Hello %s," : "Здраво %s,",
    "You are receiving this email because the following things happened at %s" : "Ову поруку сте добили јер се следеће десило на %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* и још %n","* и још %n","* и још %n"],
    "Notifications" : "Обавештења",
    "List your own actions in the stream" : "Приказ сопствених активности у записнику",
    "Notify about your own actions via email" : "Обавештење е-поштом о сопственим активностима",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења.",
    "Send emails:" : "Шаљи е-пошту:",
    "Hourly" : "сваки сат",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "Activity feed" : "Довод активности",
    "Enable RSS feed" : "Укључи РСС довод",
    "No activity yet" : "Још нема активности",
    "No more events to load" : "Нема више догађаја за приказ",
    "Files" : "Фајлови",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s и <strong class=\"has-tooltip\" title=\"%s\">још %n</strong>","%s и <strong class=\"has-tooltip\" title=\"%s\">још %n</strong>","%s и <strong class=\"has-tooltip\" title=\"%s\">још %n</strong>"]
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/sr.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "Activities" : "Активности",
    "Error loading activities" : "Грешка при учитавању активности",
    "No activities" : "Нема активности",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} и {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} и {linkStart}још %n{linkEnd}","{parameterList} и {linkStart}још %n{linkEnd}","{parameterList} и {linkStart}још %n{linkEnd}"],
    "in {directory}" : "у {directory}",
    "This stream will show events like additions, changes & shares" : "Овде ће се приказати догађаји попут додавања, измена или дељења",
    "There are no events for this filter" : "Нема догађаја за овај филтер",
    "Today" : "Данас",
    "Yesterday" : "јуче",
    "Personal activity feed for %s" : "Довод личних активности корисника %s",
    "Your feed URL is invalid" : "УРЛ вашег довода није исправан",
    "Your settings have been updated." : "Поставке су ажуриране.",
    "Mail" : "Поштом",
    "Stream" : "Записник",
    "\"remote user\"" : "\"удаљени корисник\"",
    "Activity notification" : "Обавештења о активностима",
    "All Activities" : "Све активности",
    "Activities by you" : "Ваше активности",
    "Activities by others" : "Активности других",
    "%s and %s" : "%s и %s",
    "Hello %s," : "Здраво %s,",
    "You are receiving this email because the following things happened at %s" : "Ову поруку сте добили јер се следеће десило на %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* и још %n","* и још %n","* и још %n"],
    "Notify about your own actions via email" : "Обавештење е-поштом о сопственим активностима",
    "You need to set up your email address before you can receive notification emails." : "Морате поставити адресу е-поште пре почетка пријема обавештења.",
    "Send emails:" : "Шаљи е-пошту:",
    "Hourly" : "сваки сат",
    "Daily" : "дневно",
    "Weekly" : "недељно",
    "Activity feed" : "Довод активности",
    "Enable RSS feed" : "Укључи РСС довод",
    "No activity yet" : "Још нема активности",
    "No more events to load" : "Нема више догађаја за приказ",
    "Files" : "Фајлови"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
